from setuptools import setup, find_packages


setup(
    name="ghazi",
    version=1,
    author="Ghazi",
    author_email="Ghazi123@mej.com",
    description='Ghazi library',
    long_description_content_type="text/markdown",
    long_description='Ghazi library',
    packages=find_packages(),
    keywords=['python', 'ghazi'],
    classifiers=[
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ]
)